==> flamerobin_0.7.6.orig.tar.gz: flamerobin-0.7.6-src/src/metadata/MetadataItemVisitor.cpp <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: MetadataItemVisitor.cpp 1127 2006-05-19 20:39:05Z mbabuskov $

*/
//-----------------------------------------------------------------------------

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

// for all others, include the necessary headers (this file is usually all you
// need because it includes almost all "standard" wxWindows headers
#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "MetadataItemVisitor.h"
//-----------------------------------------------------------------------------
MetadataItemVisitor::MetadataItemVisitor()
{
};
//-----------------------------------------------------------------------------
MetadataItemVisitor::~MetadataItemVisitor()
{
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitColumn(Column&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitDatabase(Database&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitDomain(Domain&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitException(Exception&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitForeignKey(ForeignKey&)
{
    defaultAction();
}
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitFunction(Function&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitGenerator(Generator&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitPrimaryKeyConstraint(PrimaryKeyConstraint&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitProcedure(Procedure&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitParameter(Parameter&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitRole(Role&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitRoot(Root&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitServer(Server&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitTable(Table&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitTrigger(Trigger&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitUniqueConstraint(UniqueConstraint&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitView(View&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitMetadataItem(MetadataItem&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------

==> flamerobin_0.8.6.orig.tar.gz: flamerobin-0.8.6-src/src/metadata/MetadataItemVisitor.cpp <==
/*
  Copyright (c) 2004-2008 The FlameRobin Development Team

  Permission is hereby granted, free of charge, to any person obtaining
  a copy of this software and associated documentation files (the
  "Software"), to deal in the Software without restriction, including
  without limitation the rights to use, copy, modify, merge, publish,
  distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to
  the following conditions:

  The above copyright notice and this permission notice shall be included
  in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: MetadataItemVisitor.cpp 1631 2008-02-02 22:25:30Z mapopa $

*/
//-----------------------------------------------------------------------------

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

// for all others, include the necessary headers (this file is usually all you
// need because it includes almost all "standard" wxWindows headers
#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "metadata/MetadataItemVisitor.h"
//-----------------------------------------------------------------------------
MetadataItemVisitor::MetadataItemVisitor()
{
};
//-----------------------------------------------------------------------------
MetadataItemVisitor::~MetadataItemVisitor()
{
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitColumn(Column&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitDatabase(Database&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitDomain(Domain&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitException(Exception&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitForeignKey(ForeignKey&)
{
    defaultAction();
}
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitFunction(Function&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitGenerator(Generator&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitPrimaryKeyConstraint(PrimaryKeyConstraint&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitProcedure(Procedure&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitParameter(Parameter&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitRole(Role&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitRoot(Root&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitServer(Server&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitTable(Table&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitTrigger(Trigger&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitUniqueConstraint(UniqueConstraint&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitView(View&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
void MetadataItemVisitor::visitMetadataItem(MetadataItem&)
{
    defaultAction();
};
//-----------------------------------------------------------------------------
